.c4
  width 50%

column()
  @extend .c4

#col3
  column 4

grid($namespace='')
  .{$namespace}one-half
    width 50%

  .{$namespace}two-quarters
    @extend .{$namespace}one-half

grid()

@media test-media
  grid('test-')
