body
  foo saturate(#ee0, 0%)
  foo saturate(#dd0, 20%)
  foo saturate(#d87240, 60%)
  foo saturate(#fd0cc7, 100%)

body
  foo saturate(rgba(35,124,46,0.5), 20%)
  foo saturate(rgba(35,124,46,0.5), 80%)

body
  foo desaturate(#ee0, 0%)
  foo desaturate(#dd0, 20%)
  foo desaturate(#d87240, 60%)
  foo desaturate(#fd0cc7, 100%)

body
  foo desaturate(rgba(35,124,46,0.5), 20%)
  foo desaturate(rgba(35,124,46,0.5), 80%)

body
  foo saturate()
  foo saturate(100%)
