body {
  foo: 118px 104px;
  foo: true;
  foo: true;
}
body {
  foo: 510px 640px;
  foo: 510px 640px;
  bar: 640px 480px;
  bar: 640px 480px;
  baz: 900px 900px;
}
body {
  foo: 0 0;
}
body.tux {
  background: url("tux.png");
}
body.foo {
  background: #0f0;
}
