
vendors = webkit

animate(name) {
  @keyframes name {
    from { color: red; }
    to { color: blue; }
  }
}

animate(something)

@-webkit-keyframes fade
  from
    opacity 0
  to
    opacity 1


@keyframes bouce {
  from {
    foo: bar;
  }

  50% {
    foo: bar;
  }

  to {
    foo: bar;
  }
}

@keyframes bouce {
  from { foo: bar; }
  50% { foo: bar; }
  to { foo: bar; }
}


@keyframes bouce {
  from { foo: bar; }
  
  
  50% { foo: bar; }
  
  to { foo: bar; }
}
