body {
  margin: 0;
  padding: 5px;
}
body ul {
/* test */
  margin: 0;
}
body ul li:first-child {
  border-top: none;
}
body ul li:last-child {
  border-bottom: none;
}
ul li:first-child,
ul li:last-child {
  display: none;
}
foo {
  border-radius: 5px;
}
foo bar baz {
  border-radius: 5px;
}
foo,
bar,
baz {
  border-radius: 5px;
}
input[type=button] {
  border-radius: 5px;
}
button,
input[type=button],
input[type=submit],
a.button {
  border-radius: 5px;
}
.foo {
  width: 10px;
}
.foo .bar {
  width: 10px;
}
