.test
  color: blend(rgba(0,0,0,0.5))
  background: blend(rgba(255,255,255,0.5), #000)
  border-color: blend(rgba(#FFF,0.7))
  border-bottom-color: blend(rgba(#FFDE00,.42), #19C261)

.test_simples
  color: blend(rgba(red, 0), lime)
  color: blend(lime, red)
  color: blend(transparent, blue)
  color: blend(rgba(lime, 0.5), rgba(red, 0.25))

.test_hsla
  color: blend(rgba(lime,.3), hsl(200,0%,0%))
  color: blend(hsla(100,50%,50%,0.5), hsla(200,0%,0%,1))
