$color = red

body
a
section
  width: 500px
  margin: 0 auto

  h2
    color: green

h1
  color: $color

/* comment */

@css {
  h3 {
    color: yellow;
  }
}

@media screen and (max-width: 500px)
  body
    color: pink
