body
  background hsla(170, 50%, 45%, 1)
  background hsla(170, 50%, 45%, 0.5)
  background hsla(170,50%,45%,0.1)
  background hsla(#39AC99)
  background hsla(#39AC99, 0.5)

  $alpha = 40%
  background hsla(#000, $alpha)
  background hsla(#000, $alpha)
  background hsla(0,0%,0%, $alpha)
  background hsla(0,0%,0%, $alpha)
