@media screen and (min-width: 1px) and (max-width: 400px) {
  body {
    display: none;
    color: #a27400;
    background-color: #a27400;
    border-color: rgba(255,202,69,0.5);
    outline-color: #400040;
    padding: 0;
    outline: 0;
    margin: 20px;
    border: #f00;
    text-decoration-color: rgba(0,0,0,0.5);
    text-shadow: 0 1px rgba(0,0,0,0.5);
  }
}
@media screen and (min-width: 1501px) {
  body {
    -webkit-transition: width 1s ease-out;
  }
}
.a {
  color: #00f;
  width: 20px;
  height: 100px;
  background: #f00;
}
.b {
  color: $params-color;
  background-color: #abc;
}
body {
  display: none;
  color: #a27400;
  background-color: #a27400;
  border-color: rgba(255,202,69,0.5);
  outline-color: #400040;
  padding: 0;
  outline: 0;
  margin: 20px;
  -webkit-transition: width 1s ease-out;
  border: #f00;
}
.icon {
  content: '';
}
body {
  test: true;
}
