body {
  padding: 15px 5px 15px 5px;
}
a.button {
  padding: 10px 10px 10px 10px;
}
a.button-2 {
  padding: 2px 10px 2px 10px;
}
body {
  padding: 10px;
}
.button {
  padding: 5px;
}
.red {
  color: #f00;
}
