a // comment
    atr def
a.class // comment
    atr def
a[href='//']
    atr def
a[href^='//']
    atr def
a[href$='//']
    atr def
a[href|='//']
    atr def
a[href~='//']
    atr def
a[href~='//']
    atr def
