body {
  foo: 1 2 3 4 5;
  foo: 1;
  foo: 5;
}
body {
  foo: 5;
  foo: 1;
  foo: 5;
}
body {
  foo: 3;
  foo: 1 2 3;
}
body {
  foo: 3;
  foo: 6;
  foo: foo bar baz foo bar baz;
}
body {
  foo: one 1 two 2 three 3;
}
body {
  foo: 1 2 3 4 5;
}
body {
  foo: 1;
  foo: 2;
  foo: 3;
}
