
@scope #sidebar 

h2
  text-transform: uppercase
  color: #888

a
  font-size: 12px
  color: #2B2B2B
  &:hover
    color: pink

.block
  margin-bottom: 20px

@scope #sidebar ul li

a
  display: block
  margin: 5px 0
  &:hover
    margin: 10px 0

@scope body.signup-page[attr='foo']

& .container
  color: red
