.clearfix:after {
  content: ".";
  display: block;
  height: 0;
  clear: both;
  visibility: hidden;
}
.clearfix {
  display: inline-block;
}
/* Hide from IE Mac \*/
.clearfix {
  display: block;
}
/* End hide from IE Mac */
.none {
  display: none;
}
/* End Clearfix */