

n = 10
a = n = n + 10
a += 1

body
  foo n
  foo a

n = 10
n += 5
n += 5

body
  foo n

n = 10
n -= 2
n -= 3

body
  foo n

n = 5
n *= 2
n *= 2

body
  foo n

n = 20
n /= 2
n /= 4

body
  foo n

n = 5
n %= 2

body
  foo n

foo ?= 'bar'
foo ?= 'baz'

body
  foo: foo

bar := 'bar'
bar := 'baz'

body
  foo: bar