
body
  foo: typeof(@foo)
  foo: @foo
  foo: '-' + @foo
  foo: '-' + @foo
  foo: '-' + @foo

body
  ul
    li
      color: blue
      color: red
      a
        color: @color

body
  foo: @bar == null
  bar: 'test'
  unless true
    bar: 'also test'
  baz: @bar
