
bold-button(bg = #333, glow = false, intensity = 1)
  intensity: intensity
  background: bg
  glow: glow

button
  bold-button(glow: 'glow', #eee)

button
  bold-button(intensity: 0.5, glow: 'glow')

button
  bold-button(intensity: 0.5, glow: 'glow', black)
