@-moz-document url-prefix() {
  .inline-button {
    padding-right: 0px;
  }
}
@-moz-document url('http://www.w3.org/'), url-prefix('http://www.w3.org/Style/'), domain('mozilla.org'), regexp("https:.*") {
  body {
    color: #800080;
    background: #ff0;
  }
}
