
border-radius(size)
  -webkit-border-radius size
  -moz-border-radius size
  border-radius size

form
  border-radius 5px

a.button
  border-radius 5px

box-shadow-important()
  push(arguments, !important)
  -webkit-box-shadow arguments
  box-shadow arguments

box-shadow = box-shadow-important

p.important
  box-shadow 1px -1px 0 1px rgba(0, 0, 0, .5)
