body {
  font-size: 12px;
}
h1 {
  font-size: 36px;
}
h2 {
  font-size: 24px;
  font: 2px;
  font: 0px;
  font: 16px;
}
body {
  foo: 100%;
  foo: 100%;
  foo: 75%;
  foo: 25%;
  foo: 0%;
  foo: 70%;
}
body {
  foo: 10em;
  foo: 10em;
}
