form input:last-child {
  display: none;
}
form input:nth-child(15) {
  display: none;
}
.grid-1 {
  width: 100px;
}
.grid-2 {
  width: 200px;
}
.grid-3 {
  width: 300px;
}
.grid-4 {
  width: 400px;
}
.grid-5 {
  width: 500px;
}
body form input:last-child {
  display: none;
}
ul li:nth-child(2) {
  display: none;
}
foo bar {
  foo: bar;
}
foo bar baz {
  foo: bar;
}
foo {
  two: 2;
}
foo bar {
  one: 1;
}
foo bar baz {
  foo: bar;
}
one * {
  one: 1;
  two: 2;
  three: 3;
}
two * {
  one: 1;
  two: 2;
  three: 3;
}
three * {
  one: 1;
  two: 2;
  three: 3;
}
.foo.bar.raz,
.foo.baz.raz {
  padding: 0;
}
.foo_hack,
x::-moz-focus-inner {
  padding: 0;
}
.foo_hack2,
x::-moz-focus-inner {
  padding: 0;
}
.foo .bar_escaped_amp[title^=&] {
  width: 10px;
}
.foo .bar_escaped_comma[title^=,&z,] {
  width: 10px;
}
.wrapper .foo,
.wrapper .bar {
  width: 10px;
}
