body
  foo 1 == 1
  foo '1' == 1
  foo 1 == '1'
  foo 1 == '5' == false
  foo 5 == 1 == false
  foo 5 != 1
  foo 5 != asdf
  foo 5 == asdf == false
  foo !(5 == '5.1')
  foo 5 != '5.1'
  foo '5' != '5.1'

body
  foo 1000ms == 1s
  foo 1s == 1000ms
  foo 1s == 500ms == false

body
  foo wahoo == wahoo
  foo wahoo == 'wahoo'
  foo wahoo == unquote('wahoo')

body
  foo unquote('wahoo') == wahoo
  foo 'wahoo' == wahoo

body
  something = 'yay'
  foo yes == (something is defined ? yes : nope)
  foo nope == (whatever is defined ? yes : nope)

body
  foo: (1 2 3) == (1 2 3)
  foo: (foo bar baz) == (foo bar baz)
  foo: () == ()

body
  foo: (foo bar baz) == (foo hey baz)
  foo: (1 2 3) == (1 2 0)
  foo: (1) == (1 2 3)
  foo: (2 2) == (2)
  foo: (2 2) == ()
  foo: () == true
  foo: true == ()
  foo: !!()

body
  foo: (1 2 3) != (1 1 3)
  foo: (foo bar baz) != (foo 1 2)
  foo: () != (1)
  foo: (1) != (0)
  foo: () != (null)

body
  foo: (1 2 3) != (1 2 3)
  foo: (foo bar) != (foo bar)
  foo: () != ()