
// foo = 'bar'

body
  color red
  // lots of stuff
  // wahoo

  // super cool

  // background green

form
  background white

/*

body
  a
    color blue

*/
// rawr

.abc
  background: // comment here,
    url("img.png") 8px 8px no-repeat,
    rgba(0, 0, 0, .41);

.popup
  -webkit-box-shadow: 1px 0 0 white, /* TODO */ 2px 0 0 black
  -moz-box-shadow: 1px 0 0 white /* TODO */ 2px 0 0 black

.foo
  color: red; /* inline */
  background: url(img.png) /* inline */;
  width: 100px;
  /* foo */
  height: 300px;

// comment with ', ", // and :
@media only screen and (max-width: 1230px)
  .test
    foo: bar

@media (max-width: 830px)
  /*!
  * uncss:ignore
  */
  nav.open .links
    transform translate(0, 0)

@font-face
  font-family: "DIN Alternate"
  src: url("DIN-Alternate-Medium.eot") /* IE9 */
  src: url("DIN-Alternate-Medium.eot?#iefix") format("embedded-opentype"), /* IE6-IE8 */
          url("DIN-Alternate-Medium.woff") format("woff"), /* chrome, firefox */
          url("DIN-Alternate-Medium.ttf") format("truetype"), /* chrome, firefox, opera, Safari, Android, iOS 4.2+ */
          url("DIN-Alternate-Medium.svg#DIN") format("svg") /* iOS 4.1- */
  font-style: normal
  font-weight: normal
