.a {
  test: '';
}
.a .b {
  test: '';
}
@media only screen and (min-width: 1024px) {
  .c {
    test: '@media (only screen and (min-width: (1024px)))';
  }
}
@media only screen and (min-width: 1024px) {
  .d {
    test: '@media (only screen and (min-width: (1024px)))';
  }
}
.e {
  test: '';
}
.e .f {
  test: '';
}
@media only screen and (min-width: 1024px) {
  .g {
    test: '@media (only screen and (min-width: (1024px)))';
  }
}
@media only screen and (min-width: 1024px) {
  .h {
    test: '@media (only screen and (min-width: (1024px)))';
  }
}
@media screen {
  .i {
    test: '@media (screen)';
  }
}
