a {
  atr: def;
}
a.class {
  atr: def;
}
a[href='//'] {
  atr: def;
}
a[href^='//'] {
  atr: def;
}
a[href$='//'] {
  atr: def;
}
a[href|='//'] {
  atr: def;
}
a[href~='//'] {
  atr: def;
}
a[href~='//'] {
  atr: def;
}
