
size = 15px
small = 5

pad-var(x, y = size)
  padding y x y x

pad-arg(x, y = x)
  padding y x y x

body
  pad-var(5px)

a.button
  pad-arg(10px)

a.button-2
  pad-arg(10px, 2px)

add(a, b)
  a + b

pad-call(n = unit(add(small, small), 'px'))
  padding n

body
  pad-call()

.button
  pad-call(5px)

get-red()
  red

set-colour(colour = get-red)
  color colour()

.red
  set-colour()
