body,
a,
section {
  width: 500px;
  margin: 0 auto;
}
body h2,
a h2,
section h2 {
  color: #008000;
}
/*# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbImJhc2ljLmlubGluZS5zdHlsIl0sIm5hbWVzIjpbXSwibWFwcGluZ3MiOiJBQUVBO0FBQ0E7QUFDQTtFQUNFLE9BQU8sTUFBUDtFQUNBLFFBQVEsT0FBUjs7QUFFQTs7O0VBQ0UsT0FBTyxRQUFQIiwiZmlsZSI6ImJhc2ljLmlubGluZS5jc3MiLCJzb3VyY2VSb290IjoiLyIsInNvdXJjZXNDb250ZW50IjpbIiRjb2xvciA9IHJlZFxuXG5ib2R5XG5hXG5zZWN0aW9uXG4gIHdpZHRoOiA1MDBweFxuICBtYXJnaW46IDAgYXV0b1xuXG4gIGgyXG4gICAgY29sb3I6IGdyZWVuXG4iXX0= */
