/* -----------------------------------------------------------------------


 Blueprint CSS Framework 1.0
 http://blueprintcss.org

   * Copyright (c) 2007-Present. See LICENSE for more info.
   * See README for instructions on how to use Blueprint.
   * For credits and origins, see AUTHORS.
   * This is a compressed file. See the sources in the 'src' directory.

----------------------------------------------------------------------- */
/* ie.css */
body {
  text-align: center;
}
.container {
  text-align: left;
}
* html .column,
* html .span-1,
* html .span-2,
* html .span-3,
* html .span-4,
* html .span-5,
* html .span-6,
* html .span-7,
* html .span-8,
* html .span-9,
* html .span-10,
* html .span-11,
* html .span-12,
* html .span-13,
* html .span-14,
* html .span-15,
* html .span-16,
* html .span-17,
* html .span-18,
* html .span-19,
* html .span-20,
* html .span-21,
* html .span-22,
* html .span-23,
* html .span-24 {
  display: inline;
  overflow-x: hidden;
}
* html legend {
  margin: 0px -8px 16px 0;
  padding: 0;
}
sup {
  vertical-align: text-top;
}
sub {
  vertical-align: text-bottom;
}
html>body p code {
  *white-space: normal;
}
hr {
  margin: -8px auto 11px;
}
img {
  -ms-interpolation-mode: bicubic;
}
.clearfix,
.container {
  display: inline-block;
}
* html .clearfix,
* html .container {
  height: 1%;
}
fieldset {
  padding-top: 0;
}
legend {
  margin-top: -0.2em;
  margin-bottom: 1em;
  margin-left: -0.5em;
}
textarea {
  overflow: auto;
}
label {
  vertical-align: middle;
  position: relative;
  top: -0.25em;
}
input.text,
input.title,
textarea {
  background-color: #fff;
  border: 1px solid #bbb;
}
input.text:focus,
input.title:focus {
  border-color: #666;
}
input.text,
input.title,
textarea,
select {
  margin: 0.5em 0;
}
input.checkbox,
input.radio {
  position: relative;
  top: 0.25em;
}
form.inline div,
form.inline p {
  vertical-align: middle;
}
form.inline input.checkbox,
form.inline input.radio,
form.inline input.button,
form.inline button {
  margin: 0.5em 0;
}
button,
input.button {
  position: relative;
  top: 0.25em;
}
