body form input.hide,
body foo bar,
body .hidden,
body:hover,
body:focus {
  display: none;
}
body form input,
body .hidden {
  display: none;
}
ul > li {
  padding: 5px;
  border: 1px solid #eee;
}
ul > li:first-child,
ul > li:last-child {
  border: none;
}
ul > li:first-child {
  padding-top: 0;
}
ul > li:last-child {
  padding-bottom: 0;
}
body form > input:nth-child(2) {
  border: 1px solid #eee;
}
.foo {
  bar: baz;
}
.foo-2x .bar {
  baz: quux;
}
.foo-3x.foo {
  baz: qux;
}
