$r = #C44444
$h = hsl(#C44444)

// TODO: hsl() percentages

body
  foo: $r + 10
  foo: $h + 10

body
  foo $r - 10
  foo $h - 10

body
  foo $r + 20%
  foo $h + 20%

body
  foo $r - 20%
  foo $h - 20%

body
  foo $r + 20deg
  foo $h + 20deg

body
  foo $r - 20deg
  foo $h - 20deg

body
  foo $r + rgb(0,50,100)
  foo $h + rgb(0,50,100)

body
  foo $r + rgb(0,50,100)
  foo $h - rgb(0,50,100)

body
  foo $r + hsl(20,30,10)
  foo $h + hsl(20,30,10)

body
  foo $r - hsl(20,30,10)
  foo $h - hsl(20,30,10)

body
  color: (#eee + 50%) == lighten(#eee, 50%)
  color: (#eee - 50%) == darken(#eee, 50%)