h1#logo {
  margin-top: -15px;
  margin-left: 3px;
  foo: false;
  foo: false;
  foo: false;
  foo: false;
  foo: false;
  foo: false;
  foo: 0px -2px -3px;
  foo: 1px;
}
body {
  text-indent: -99999px;
  background: #fff url("/some/image.png") no-repeat -29px 1px;
}