.embed-no-hash {
  color: #c00;
  background: url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPHN2ZyB3aWR0aD0iMTIwIiBoZWlnaHQ9IjEyMCIgdmlld1BvcnQ9IjAgMCAxMjAgMTIwIiB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgICA8Y2lyY2xlIGN4PSI2MCIgY3k9IjYwIiByPSI1MCIvPgo8L3N2Zz4K");
}
.embed-with-hash {
  color: #c00;
  background: url("data:image/svg+xml;base64,PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0idXRmLTgiPz4KPHN2ZyB3aWR0aD0iMTIwIiBoZWlnaHQ9IjEyMCIgdmlld1BvcnQ9IjAgMCAxMjAgMTIwIiB2ZXJzaW9uPSIxLjEiIHhtbG5zPSJodHRwOi8vd3d3LnczLm9yZy8yMDAwL3N2ZyI+CiAgICA8Y2lyY2xlIGN4PSI2MCIgY3k9IjYwIiByPSI1MCIvPgo8L3N2Zz4K#some-id");
}
.embed-with-utf8 {
  color: #c00;
  background: url("data:image/svg+xml;charset=utf-8,%3C?xml version=%221.0%22 encoding=%22utf-8%22?%3E %3Csvg width=%22120%22 height=%22120%22 viewPort=%220 0 120 120%22 version=%221.1%22 xmlns=%22http://www.w3.org/2000/svg%22%3E %3Ccircle cx=%2260%22 cy=%2260%22 r=%2250%22/%3E %3C/svg%3E");
}
.too-big-no-hash {
  color: #c00;
  background: url("tiger.svg");
}
.too-big-with-hash {
  color: #c00;
  background: url("tiger.svg#some-id");
}
