
add(a, b)
  div(a, b)
    a / b
  a + div(b, 2)

body
  padding add(1,5)
  // => 3.5

add(a, b)
  half()
    b / 2
  a + half()

body
  padding add(1,5)
  // => 3.5

getFunction(name)
  if name == 'add'
    add(a, b)
      a + b
  else
    sub(a, b)
      a - b

body
  fn = getFunction('add')
  padding fn(5, 5)
  // => 10
  
  fn = getFunction('sub')
  fn2 = fn
  fn3 = fn2
  padding fn3(5, 5)
  // => 0