input::selection
input::focus-inner
  border: 0
  padding: 0

input::-moz-selection
  border: 0

p
::selection
  background: black

::selection
  background: black

p::selection
a::selection
  background: black

p::selection {
  color: white;
  background: black;
}

vendors = webkit

body
  ::selection
    color: white
