.test1
  color: transparentify(#FFF)

.test2
  color: transparentify(#000)

.test3
  color: transparentify(#808080)

.test4
  color: transparentify(#808080, #000)

.test5
  color: transparentify(#414141, #000)

.test6
  color: transparentify(#FF7F7F)

.test7
  color: transparentify(#BDDDD8)

.test8
  color: transparentify(#7E3B65)

.test9
  color: transparentify(#91974C, #F34949)

.test10
  color: transparentify(#91974C, #F34949, 0.5)

.test11
  color: transparentify(#808080, 0.7)

.test12
  color: transparentify(#808080, #000, 0.7)

.test13
  color: transparentify(#AE1268, #E93636)

.test14
  color: transparentify(hsla(200,40%,40%,.3), hsla(200,0%,100%,1))
