body {
  color: 204;
}
body {
  font: 14px 'Lucida Grande', Arial, sans-serif;
  padding: 5px;
  margin: 5px;
}
a {
  font: 11px Impact, 'Lucida Grande', Arial, sans-serif, serif;
  border: 1px solid #fff;
  color: #fff;
  background: 10px #ddd;
  margin: 14px;
}
@media screen and (max-width: 1024px) {
  a {
    background: 20px #ccc;
  }
}
.test div input.margin[type] {
  padding: 20px;
}
.test div input.margin[type] div input.margin[type=text] {
  color: #f00;
}
a.margin,
em {
  padding: 10px 20px;
  margin: 10px 20px 30px 40px;
  padding-left: 10px;
}
a.margin-pin,
em-pin {
  absolute: top -11px;
  background-color: #ddd;
  top: 10px;
}
.test1 {
  background-color: #ddd;
}
.test1_size_s {
  height: 12px;
  font-size: 13px;
}
.test1_size_s.test1_shape_square {
  width: 12px;
}
.test1_size_m {
  height: 14px;
  font-size: 15px;
}
.test1_size_m.test1_shape_square {
  width: 14px;
}
.test1_size_l {
  height: 17px;
  font-size: 18px;
}
.test1_size_l.test1_shape_square {
  width: 17px;
}
.test2__modal-body {
  margin-top: 11px;
  font-size: 6px;
}
.test {
  background: linear-gradient(rgba(255,255,255,0) 0%, #f0f 90%);
  background-color: #ddd;
  height: 10px;
  line-height: 10px;
}
.test_some {
  color: #f00;
  background: #ddd;
}
.classA {
  font: 14px;
  border: 1px solid #fff;
}
.classB {
  @apply classA;
}
.test-pseudo {
  font-size: 12px;
}
.test-pseudo table.section tr td:nth-child(n + 1) {
  font-size: 10px;
}
