body {
  color-aliceblue: #f0f8ff;
  color-antiquewhite: #faebd7;
  color-aqua: #0ff;
  color-aquamarine: #7fffd4;
  color-azure: #f0ffff;
  color-beige: #f5f5dc;
  color-bisque: #ffe4c4;
  color-black: #000;
  color-blanchedalmond: #ffebcd;
  color-blue: #00f;
  color-blueviolet: #8a2be2;
  color-brown: #a52a2a;
  color-burlywood: #deb887;
  color-cadetblue: #5f9ea0;
  color-chartreuse: #7fff00;
  color-chocolate: #d2691e;
  color-coral: #ff7f50;
  color-cornflowerblue: #6495ed;
  color-cornsilk: #fff8dc;
  color-crimson: #dc143c;
  color-cyan: #0ff;
  color-darkblue: #00008b;
  color-darkcyan: #008b8b;
  color-darkgoldenrod: #b8860b;
  color-darkgray: #a9a9a9;
  color-darkgreen: #006400;
  color-darkgrey: #a9a9a9;
  color-darkkhaki: #bdb76b;
  color-darkmagenta: #8b008b;
  color-darkolivegreen: #556b2f;
  color-darkorange: #ff8c00;
  color-darkorchid: #9932cc;
  color-darkred: #8b0000;
  color-darksalmon: #e9967a;
  color-darkseagreen: #8fbc8f;
  color-darkslateblue: #483d8b;
  color-darkslategray: #2f4f4f;
  color-darkslategrey: #2f4f4f;
  color-darkturquoise: #00ced1;
  color-darkviolet: #9400d3;
  color-deeppink: #ff1493;
  color-deepskyblue: #00bfff;
  color-dimgray: #696969;
  color-dimgrey: #696969;
  color-dodgerblue: #1e90ff;
  color-firebrick: #b22222;
  color-floralwhite: #fffaf0;
  color-forestgreen: #228b22;
  color-fuchsia: #f0f;
  color-gainsboro: #dcdcdc;
  color-ghostwhite: #f8f8ff;
  color-gold: #ffd700;
  color-goldenrod: #daa520;
  color-gray: #808080;
  color-grey: #808080;
  color-green: #008000;
  color-greenyellow: #adff2f;
  color-honeydew: #f0fff0;
  color-hotpink: #ff69b4;
  color-indianred: #cd5c5c;
  color-indigo: #4b0082;
  color-ivory: #fffff0;
  color-khaki: #f0e68c;
  color-lavender: #e6e6fa;
  color-lavenderblush: #fff0f5;
  color-lawngreen: #7cfc00;
  color-lemonchiffon: #fffacd;
  color-lightblue: #add8e6;
  color-lightcoral: #f08080;
  color-lightcyan: #e0ffff;
  color-lightgoldenrodyellow: #fafad2;
  color-lightgray: #d3d3d3;
  color-lightgreen: #90ee90;
  color-lightgrey: #d3d3d3;
  color-lightpink: #ffb6c1;
  color-lightsalmon: #ffa07a;
  color-lightseagreen: #20b2aa;
  color-lightskyblue: #87cefa;
  color-lightslategray: #789;
  color-lightslategrey: #789;
  color-lightsteelblue: #b0c4de;
  color-lightyellow: #ffffe0;
  color-lime: #0f0;
  color-limegreen: #32cd32;
  color-linen: #faf0e6;
  color-magenta: #f0f;
  color-maroon: #800000;
  color-mediumaquamarine: #66cdaa;
  color-mediumblue: #0000cd;
  color-mediumorchid: #ba55d3;
  color-mediumpurple: #9370db;
  color-mediumseagreen: #3cb371;
  color-mediumslateblue: #7b68ee;
  color-mediumspringgreen: #00fa9a;
  color-mediumturquoise: #48d1cc;
  color-mediumvioletred: #c71585;
  color-midnightblue: #191970;
  color-mintcream: #f5fffa;
  color-mistyrose: #ffe4e1;
  color-moccasin: #ffe4b5;
  color-navajowhite: #ffdead;
  color-navy: #000080;
  color-oldlace: #fdf5e6;
  color-olive: #808000;
  color-olivedrab: #6b8e23;
  color-orange: #ffa500;
  color-orangered: #ff4500;
  color-orchid: #da70d6;
  color-palegoldenrod: #eee8aa;
  color-palegreen: #98fb98;
  color-paleturquoise: #afeeee;
  color-palevioletred: #db7093;
  color-papayawhip: #ffefd5;
  color-peachpuff: #ffdab9;
  color-peru: #cd853f;
  color-pink: #ffc0cb;
  color-plum: #dda0dd;
  color-powderblue: #b0e0e6;
  color-purple: #800080;
  color-red: #f00;
  color-rosybrown: #bc8f8f;
  color-royalblue: #4169e1;
  color-saddlebrown: #8b4513;
  color-salmon: #fa8072;
  color-sandybrown: #f4a460;
  color-seagreen: #2e8b57;
  color-seashell: #fff5ee;
  color-sienna: #a0522d;
  color-silver: #c0c0c0;
  color-skyblue: #87ceeb;
  color-slateblue: #6a5acd;
  color-slategray: #708090;
  color-slategrey: #708090;
  color-snow: #fffafa;
  color-springgreen: #00ff7f;
  color-steelblue: #4682b4;
  color-tan: #d2b48c;
  color-teal: #008080;
  color-thistle: #d8bfd8;
  color-tomato: #ff6347;
  color-transparent: transparent;
  color-turquoise: #40e0d0;
  color-violet: #ee82ee;
  color-wheat: #f5deb3;
  color-white: #fff;
  color-whitesmoke: #f5f5f5;
  color-yellow: #ff0;
  color-yellowgreen: #9acd32;
  color-rebeccapurple: #639;
}
