body {
  foo: 10;
  foo: 20;
  foo: 10;
}
body {
  foo: 'foo bar baz';
  foo: 'foo, bar, baz';
  foo: '1 2 3';
  foo: '1, 2, 3';
}
body {
  foo: 0 Impact;
  foo: 1 Arial;
  foo: 2 sans-serif;
}
body {
  foo: 24;
  foo: 30;
}