form input {
  border: 1px solid #eee;
}
[type='text'] {
  margin: 0;
}
input[type='text'] {
  display: none;
}
input[type='password'],
select {
  background: #eee;
}
body {
  font: 12px;
}
caption[attr='foo'] + th:first-child {
  color: #f00;
}
div > div:first-child > :first-child {
  color: #00f;
}
