@-webkit-keyframes something {
  from {
    color: #f00;
  }
  to {
    color: #00f;
  }
}
@-webkit-keyframes fade {
  from {
    opacity: 0;
  }
  to {
    opacity: 1;
  }
}
@-webkit-keyframes bouce {
  from {
    foo: bar;
  }
  50% {
    foo: bar;
  }
  to {
    foo: bar;
  }
}
@-webkit-keyframes bouce {
  from {
    foo: bar;
  }
  50% {
    foo: bar;
  }
  to {
    foo: bar;
  }
}
@-webkit-keyframes bouce {
  from {
    foo: bar;
  }
  50% {
    foo: bar;
  }
  to {
    foo: bar;
  }
}
