form .foo {
  color: #000;
}
form .foo .bar {
  padding: 5px;
  color: #f00;
}
body .foo .bar {
  display: none;
}
body .foo .baz,
body .bar .baz,
body .foo .sdf,
body .bar .sdf {
  display: none;
}
.foo .baz,
.bar .baz,
.foo .raz,
.bar .raz {
  something: 'else';
}
.foo .baz,
.bar .baz,
.foo .raz,
.bar .raz {
  background: #f00;
}
.foo .baz .ASDF,
.bar .baz .ASDF,
.foo .raz .ASDF,
.bar .raz .ASDF {
  background: #fff;
}
.circle img,
.circle .cap-overlay,
.circle .cap-soldout {
  border-radius: 200px;
}
tag .class,
bar {
  foo: bar;
}
