body
  form input.hide,
  foo bar,
  .hidden
  &:hover
  &:focus
    display none

body
  form input, .hidden
    display none

ul
  > li
    padding 5px
    border 1px solid #eee
    &:first-child,
    &:last-child
      border none
    &:first-child
      padding-top 0
    &:last-child
      padding-bottom 0

body
  form > input:nth-child(2)
    border 1px solid #eee

.foo
  bar baz

  &-2x .bar
    baz quux

  &-3x.foo
    baz qux
