@import url('http://foo.com/foo.css')
@import url("http://foo.com/foo.css")
@import url('https://foo.com/foo.css')
@import url('//foo.com/foo.css')
@import "http://foo.com/foo.css"
@import 'https://foo.com/foo.css'
@import '//foo.com/foo.css'
@import 'http://foo.com/foo.css'
@import url('#')
