@font-face {
  font-family: "Your typeface";
  src: url("type/filename.eot");
}
@font-face {
  font-family: 'SPEdessa';
  src: url("fonts/spedessa-webfont.eot");
  src: url("fonts/spedessa-webfont.eot?#iefix") format('embedded-opentype'), url("fonts/spedessa-webfont.woff") format('woff'), url("fonts/spedessa-webfont.ttf") format('truetype');
  font-weight: normal;
  font-style: normal;
}
@font-face {
  font-family: 'ekibastuzregular';
}
