.foo
  width: 10px

foo()
  .bar
    {block}

+prefix-classes('prefix-')
  .test
    width: 1px
  .test2
    width: 1px

+prefix-classes('prefix-')
  .test
    width: 1px
    .test2
      width: 1px
      ../ .test3
        color: blue
      .test4
        .test5
          ^[1..-2] .test6
            color: green

+foo()
  width: 10px
  +prefix-classes('prefix2-')
    .test
      width: 1px
    .test2
      width: 1px


+prefix-classes('lol-')
  .bar
    height: 10px

  @import 'import.basic/a'
