    // foo
// bar
  // baz


/** main **/

body{} 

body {}
  // foo
    // bar

body
  color: red
  // baz
    // qux
    // foo
      // bar
   // buz
  border: 1px solid blue

body {
  // comment
    // another
  // one
  color: blue
  a {
    color: red
  }
}

body
  /*.nested*/
    /*color: red*/

body {
  color: blue
  .nested {
    color: red
    }
  }

body { color: red;   width:  100px }

body {color:#666}
    a:hover {color:#333}

h1
  font-family 'Economica', sans-serif

a:hover
  color black

@media screen
{
  body
  {
    color: red;
  }
}

@keyframes foo
{
  from
  {
    color: red;
  }
  to
  {
    color: blue;
  }
}

body
  // color: red
    // background: blue
