
size = 12px
large = size * (3 - 1)
huge = size * 3

body
  font-size size

h1
  font-size huge

h2
  font-size large
  font 5px % 3
  font 5px % 5
  font 2px ** 4
  y = 10
  x = 15

body {
  foo: 50% * 2;
  foo: 2 * 50%;
  foo: 50 + 50%;
  foo: 50 - 50%;
  foo: 50% - 50%;
  foo: 50% + 20%;
}
body {
  foo: 5 + 5em;
  foo: 5em + 5;
}
