body {
  foo: 'null';
  foo: 'null';
  foo: '-null';
  foo: '--null';
  foo: '---null';
}
body ul li {
  color: #00f;
  color: #f00;
}
body ul li a {
  color: #f00;
}
body {
  foo: true;
  bar: 'test';
  baz: 'test';
}
