body {
  foo: 'baz';
  foo: 'baz';
  foo: 'bar';
  foo: 'bar';
}
body {
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
}
body {
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: -5;
}
