body
  border-type = solid
  size = 15px
  background type('test')
  background type(12px)
  background type(12)
  background type(hsl(100deg, 50%, 50%))
  background type(#fff)
  background type(something)
  background type(size)
  background type(type)
  background type(border-type)