.math
  test1: ceil(0.5)
  test2: floor(0.5)
  test3: round(0.5)
.math_units
  test1: ceil(0.5px)
  test2: floor(0.5px)
  test3: round(0.5px)
.math_precision0
  test1: ceil(0.47,0)
  test2: floor(0.47,0)
  test3: round(0.47,0)
.math_precision1
  test1: ceil(0.47,1)
  test2: floor(0.47,1)
  test3: round(0.47,1)
.math_precision2
  test1: ceil(0.472,2)
  test2: floor(0.472,2)
  test3: round(0.472,2)

.math_PI
  foo: PI

.math_sin
  test1: sin(0)
  test2: sin(30deg)
  test3: sin(45deg)
  test4: sin(60deg)
  test5: sin(90deg)
  test6: sin(180deg)
  test7: sin(270deg)
  test8: sin(360deg)
  test9: sin(0rad)
  test10: sin(1rad)

.math_cos
  test1: cos(0)
  test2: cos(30deg)
  test3: cos(45deg)
  test4: cos(60deg)
  test5: cos(90deg)
  test6: cos(180deg)
  test7: cos(270deg)
  test8: cos(360deg)
  test9: cos(0rad)
  test10: cos(1rad)

.math_tan
  test1: tan(0)
  test2: tan(30deg)
  test3: tan(45deg)
  test4: tan(60deg)
  test5: tan(90deg)
  test6: tan(180deg)
  test7: tan(270deg)
  test8: tan(360deg)

.math_sin_rad
  test1: sin(2*PI/3)
  test2: sin(3*PI/4)
  test3: sin(5*PI/6)
  test4: sin(7*PI/6)
  test5: sin(5*PI/4)
  test6: sin(4*PI/3)
  test7: sin(5*PI/3)
  test8: sin(7*PI/4)
  test9: sin(11*PI/6)
