
add(a, b)
  a + b

size-function = add

size(n)
  size-function(n, n)

padding-x(n)
  padding-left n
  padding-right n

padding-y(n)
  padding-top n
  padding-bottom n

mixin(name, n)
  name(n)

body
  fn = padding-x
  font size(14px)
  fn(5px)

form
  mixin(padding-y, 10px)