
large(n)
  unless n is a 'unit'
    return false
  if n > 100
    yes
  else
    no

awesome()
  yes

nested(a = 5)
  if a is a 'unit'
    b = 10
    if a
      c = 100
      c = 100
      c = 100
      c = 100
      awesome()
    else
      'b is not a unit'
  else
    'a is not a unit'

set()
  1
  return 2
  3

body
  // no
  foo large(15)
  
  // yes
  foo large(150)

  // false
  foo large('string')
  
  // yes
  foo nested()
  
  // 'a is not a unit'
  foo nested('wahoo')

  // 2
  foo set()

deep-implicit()
  one
  if false
    two
  else
    if true
      something
      three
    else
      four
  five

deep-explicit()
  one
  if false
    two
  else
    if true
      return something
      three
    else
      four
  five

body
  foo deep-implicit()
  foo deep-explicit()

test()
  return 1 if false
  return 2 if false
  return 3 if true
  return 4

body
  foo test()