body
  foo 5px + '5'
  foo 5px + '1 23'
  foo 'foo ' + 'bar'
  foo 'value: ' + 5px
  foo 1mm + 2mm
  foo 10mm + 2in
  foo 1cm + 20mm
  foo 1cm + 2in
  foo 1in + 25.4mm
  foo 1in + 2.54cm
  foo (100cm / 2cm)
  foo 10pt + 1mm
  foo bar + 10px
  foo bar + 10em
  foo bar + 10
