body {
  foo: true;
  foo: 3 4 5;
  foo: true;
  foo: true;
  foo: false;
  foo: -5;
}
body {
  foo: 1 2 3 4;
  foo: 1;
  foo: 2 3 4;
  foo: 2;
  foo: 3 4;
  foo: 3;
  foo: 4;
  foo: ;
}
body {
  foo: error;
  foo: 'message';
}
body {
  foo: 5;
  foo: 10;
}
body {
  foo: 5;
  foo: 10;
}
body {
  foo: 1 2;
  foo: 3 4;
  foo: 4;
}
body {
  foo: 100 200;
  foo: 100;
  foo: 200;
  foo: 2;
}
body {
  foo: 100 200;
  foo: 100;
  foo: 200;
  foo: 2;
}
body {
  foo: 100 200;
  foo: 100;
  foo: 200;
  foo: 2;
}
body {
  foo: 100 200;
  foo: 100;
  foo: 200;
  foo: 2;
}