
mixin()
  td:nth-of-type(2)
  td:nth-of-type(3)
    background black

ul
  mixin()

table
  td:nth-child(2)
  td:nth-child(3)
  td:nth-child(4)
  td:nth-child(5)
  td:first-letter
    background black
    li:first-child
    li:last-child
      background white

table
  :nth-child(2)
  :nth-child(3)
    background black

table
  td:after, td .after
    background red
  td
    background white

table
  td:before, td::before
    color green
  td:selection, td::selection
    color red
  td:first-line
    color yellow
  td::first-letter
    color black

label
  input:indeterminate
  span
    color #001
  input:checked
  span
    color #002
  a:any-link
  span
    color #003
  a:local-link
  span
    color #004
  input:read-only
  span
    color #005
  input:read-write
  span
    color #006
  input:placeholder-shown
  span
    color #007
  // input:default
  // span
  //   color #008
  //  throws illegal unary "in", missing left-hand operand
  // input:in-range
  // span
  //   color #009
  input:out-of-range
  span
    color #010
  input:required
  span
    color #011
  input:optional
  span
    color #012
  input:user-error
  span
    color #013
  input:blank
  span
    color #014
