foo = '100px'
bar = '#c00'
baz = 'something'

body
  test: type(convert(foo))
  test: type(convert(bar))
  test: type(convert(baz))
  list = convert('10 20 30 40')
  list2 = convert('10, 20, 30, 40')
  push(list, 50)
  test: list
  test: list-separator(list) == ' '
  test: list-separator(list2) == ','
  test: 10em + convert('1.334em')
  test: 10em + convert('-4.5em')
