body
  color-aliceblue: aliceblue
  color-antiquewhite: antiquewhite
  color-aqua: aqua
  color-aquamarine: aquamarine
  color-azure: azure
  color-beige: beige
  color-bisque: bisque
  color-black: black
  color-blanchedalmond: blanchedalmond
  color-blue: blue
  color-blueviolet: blueviolet
  color-brown: brown
  color-burlywood: burlywood
  color-cadetblue: cadetblue
  color-chartreuse: chartreuse
  color-chocolate: chocolate
  color-coral: coral
  color-cornflowerblue: cornflowerblue
  color-cornsilk: cornsilk
  color-crimson: crimson
  color-cyan: cyan
  color-darkblue: darkblue
  color-darkcyan: darkcyan
  color-darkgoldenrod: darkgoldenrod
  color-darkgray: darkgray
  color-darkgreen: darkgreen
  color-darkgrey: darkgrey
  color-darkkhaki: darkkhaki
  color-darkmagenta: darkmagenta
  color-darkolivegreen: darkolivegreen
  color-darkorange: darkorange
  color-darkorchid: darkorchid
  color-darkred: darkred
  color-darksalmon: darksalmon
  color-darkseagreen: darkseagreen
  color-darkslateblue: darkslateblue
  color-darkslategray: darkslategray
  color-darkslategrey: darkslategrey
  color-darkturquoise: darkturquoise
  color-darkviolet: darkviolet
  color-deeppink: deeppink
  color-deepskyblue: deepskyblue
  color-dimgray: dimgray
  color-dimgrey: dimgrey
  color-dodgerblue: dodgerblue
  color-firebrick: firebrick
  color-floralwhite: floralwhite
  color-forestgreen: forestgreen
  color-fuchsia: fuchsia
  color-gainsboro: gainsboro
  color-ghostwhite: ghostwhite
  color-gold: gold
  color-goldenrod: goldenrod
  color-gray: gray
  color-grey: grey
  color-green: green
  color-greenyellow: greenyellow
  color-honeydew: honeydew
  color-hotpink: hotpink
  color-indianred: indianred
  color-indigo: indigo
  color-ivory: ivory
  color-khaki: khaki
  color-lavender: lavender
  color-lavenderblush: lavenderblush
  color-lawngreen: lawngreen
  color-lemonchiffon: lemonchiffon
  color-lightblue: lightblue
  color-lightcoral: lightcoral
  color-lightcyan: lightcyan
  color-lightgoldenrodyellow: lightgoldenrodyellow
  color-lightgray: lightgray
  color-lightgreen: lightgreen
  color-lightgrey: lightgrey
  color-lightpink: lightpink
  color-lightsalmon: lightsalmon
  color-lightseagreen: lightseagreen
  color-lightskyblue: lightskyblue
  color-lightslategray: lightslategray
  color-lightslategrey: lightslategrey
  color-lightsteelblue: lightsteelblue
  color-lightyellow: lightyellow
  color-lime: lime
  color-limegreen: limegreen
  color-linen: linen
  color-magenta: magenta
  color-maroon: maroon
  color-mediumaquamarine: mediumaquamarine
  color-mediumblue: mediumblue
  color-mediumorchid: mediumorchid
  color-mediumpurple: mediumpurple
  color-mediumseagreen: mediumseagreen
  color-mediumslateblue: mediumslateblue
  color-mediumspringgreen: mediumspringgreen
  color-mediumturquoise: mediumturquoise
  color-mediumvioletred: mediumvioletred
  color-midnightblue: midnightblue
  color-mintcream: mintcream
  color-mistyrose: mistyrose
  color-moccasin: moccasin
  color-navajowhite: navajowhite
  color-navy: navy
  color-oldlace: oldlace
  color-olive: olive
  color-olivedrab: olivedrab
  color-orange: orange
  color-orangered: orangered
  color-orchid: orchid
  color-palegoldenrod: palegoldenrod
  color-palegreen: palegreen
  color-paleturquoise: paleturquoise
  color-palevioletred: palevioletred
  color-papayawhip: papayawhip
  color-peachpuff: peachpuff
  color-peru: peru
  color-pink: pink
  color-plum: plum
  color-powderblue: powderblue
  color-purple: purple
  color-red: red
  color-rosybrown: rosybrown
  color-royalblue: royalblue
  color-saddlebrown: saddlebrown
  color-salmon: salmon
  color-sandybrown: sandybrown
  color-seagreen: seagreen
  color-seashell: seashell
  color-sienna: sienna
  color-silver: silver
  color-skyblue: skyblue
  color-slateblue: slateblue
  color-slategray: slategray
  color-slategrey: slategrey
  color-snow: snow
  color-springgreen: springgreen
  color-steelblue: steelblue
  color-tan: tan
  color-teal: teal
  color-thistle: thistle
  color-tomato: tomato
  color-transparent: transparent
  color-turquoise: turquoise
  color-violet: violet
  color-wheat: wheat
  color-white: white
  color-whitesmoke: whitesmoke
  color-yellow: yellow
  color-yellowgreen: yellowgreen
  color-rebeccapurple: rebeccapurple
