body {
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
}
body {
  foo: true;
  foo: true;
  foo: true;
}
body {
  foo: true;
  foo: true;
  foo: true;
}
body {
  foo: true;
  foo: true;
}
body {
  foo: true;
  foo: true;
}
body {
  foo: true;
  foo: true;
  foo: true;
}
body {
  foo: false;
  foo: false;
  foo: false;
  foo: false;
  foo: false;
  foo: false;
  foo: false;
  foo: false;
}
body {
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: true;
}
body {
  foo: false;
  foo: false;
  foo: false;
}
