body {
  padding: 5px;
  color: 'bar';
}
body .foo {
  color: 'bar';
}
body .foo .bar {
  color: 'bar';
}
body {
  one: 1;
  two: 2;
  three: 3;
}
body with some nesting {
  four: 4;
}
body with some nesting even more {
  five: 5;
}