
pad(size = small)
  if large == size
    padding 20px
  if medium == size
    padding 10px
  if small == size
    padding 3px

body
  pad(large)
  pad(medium)
  pad()
  pad(invalid)

nested(val)
  if val
    foo bar
    bar baz
    .two
      level two
      &:hover
        level three

form input
  nested(true)
  nested(false)

break()
  foo bar
  bar baz
  return
  baz raz

body
  break()