body {
  foo: 3;
  foo: 1 2;
}
body {
  foo: 3;
  foo: 2;
  foo: 1;
}
body {
  foo: 1;
  foo: 0;
}
body {
  foo: ;
  foo: 0;
}
body {
  foo: 4;
  foo: 5 6;
}
body {
  foo: 4;
  foo: 5;
  foo: 6;
}
body {
  foo: 4;
  foo: 0;
}
body {
  foo: ;
  foo: 0;
}