
color = hsla(0,0,0,0)

body
  foo: color is a 'color'
  foo: color == color
  foo: color != color
  foo: color >= color
  foo: color <= color
  foo: color > color
  foo: color < color
  foo: color and 'ok'
  foo: color ? 'ok' : 'nope'
  foo: !! color
  foo: color in (foo bar baz)
  foo: color in (foo color baz)