
body
  n = 5
  foo: (n)em
  foo: (n) em
  foo: (n)%
  foo: (n) %
  foo: (n + 5)%
  foo: (n * 5)px
  foo: (5 + 180 / 2)deg

body
  n = 5 * 5
  foo: (n)deg

body
  foo: foo bar (1)pt
  foo: foo bar (2 * 5)px
  foo: foo (2 * 5 + (5 * 55))px bar
