body {
  background: url("/images/foo.png");
  background: url("/images/foo.png");
  background: url("/images/foo.png");
  background: url("/images/foo.png");
  background: url("/images/foo.png");
  background: url("/images/foo.png");
  background: url("/images/foo.png");
  background: url("/images/foo.png");
  background: url("/images/foo.png");
  background: url("http://foo.com/images/bar.png");
  background: url("//foo.com/images/bar.png");
}
