body {
  padding: 20px;
  padding: 10px;
  padding: 3px;
}
form input {
  foo: bar;
  bar: baz;
}
form input .two {
  level: two;
}
form input .two:hover {
  level: three;
}
body {
  foo: bar;
  bar: baz;
}