
body
  color: fade-out(#eee, .2)
  color: fade-out(#eee, .5)
  color: fade-in(rgba(#eee, .5), .5)
  color: fade-in(rgba(#eee, .2), .2)

.test-percent-values
  color: fade-out(#eee, 20%)
  color: fade-out(#eee, 50%)
  color: fade-in(rgba(#eee, 50%), 50%)
  color: fade-in(rgba(#eee, 20%), 20%)
