#login {
  -webkit-border-radius: 1px 2px/3px 4px;
  -moz-border-radius: 1px 2px/3px 4px;
  border-radius: 1px 2px/3px 4px;
}
body {
  foo: bar;
  foo-something: foo;
  foo-something-bar: foo;
  something-foo: foo;
  something: foo;
}
body {
  test-stuff-yup: awesome;
  -webkit-border-radius: awesome;
  -webkit-box-shadow: awesome;
}
body {
  foo: 'one';
  foo: 'two';
}
body {
  -webkit-something: foo;
  something: foo;
}
body form input {
  -webkit-something: foo;
  something: foo;
}
body form input p {
  something: foo;
}
body {
  foo-test-baz: bar;
  foo-test: bar;
  test: bar;
  position: absolute;
  top: 0;
  right: 0;
}