/** main **/
body {
  color: #f00;
  border: 1px solid #00f;
}
body {
  color: #00f;
}
body a {
  color: #f00;
}
body {
  color: #00f;
}
body .nested {
  color: #f00;
}
body {
  color: #f00;
  width: 100px;
}
body {
  color: #666;
}
a:hover {
  color: #333;
}
h1 {
  font-family: 'Economica', sans-serif;
}
a:hover {
  color: #000;
}
@media screen {
  body {
    color: #f00;
  }
}
@-moz-keyframes foo {
  from {
    color: #f00;
  }
  to {
    color: #00f;
  }
}
@-webkit-keyframes foo {
  from {
    color: #f00;
  }
  to {
    color: #00f;
  }
}
@-o-keyframes foo {
  from {
    color: #f00;
  }
  to {
    color: #00f;
  }
}
@keyframes foo {
  from {
    color: #f00;
  }
  to {
    color: #00f;
  }
}
