html>body p code {*white-space:normal;}

body
  *white-space normal

body
  *white-space: normal

mixin()
  *white-space: normal

body
  mixin()

mixin()
  *white-space normal

* foo
  display: none

body
  *
    display: none

body
  mixin()

mixin()
  * foo
    bar: baz

body
  mixin()

body * foo {
  display: none
}