body {
  background: #39ac99;
  background: rgba(57,172,153,0.5);
  background: rgba(57,172,153,0.1);
  background: #39ac99;
  background: rgba(57,172,153,0.5);
  background: rgba(0,0,0,0.4);
  background: rgba(0,0,0,0.4);
  background: rgba(0,0,0,0.4);
  background: rgba(0,0,0,0.4);
}
