.negative-property-lookup
    margin-top: 20px;
    bottom: -@margin-top;
    top: -@margin-top + 10px;

.another-example
    margin-top: 20px;
    bottom: - @margin-top;
    top: -(@margin-top) + 10px;
