body {
  background: 'string';
  background: 'unit';
  background: 'unit';
  background: 'hsla';
  background: 'rgba';
  background: 'ident';
  background: 'unit';
  background: 'function';
  background: 'ident';
}