@-moz-viewport {
  color: #f00;
}
@viewport {
  color: #00f;
}
@host {
  body {
    color: #008000;
  }
}
@foo {
  @bar {
    color: #cc0;
  }
}
@foo {}
@foo {}
@foo;
@namespace svg "http://www.w3.org/2000/svg";
@namespace "foo";
@namespace foo "http://example.com/foo";
@namespace xul url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul");
@namespace url("http://www.w3.org/1999/xhtml");
@region div.region:first-of-type {
  p {
    color: #fff;
  }
}
@media screen and (max-width: 400px) {
  @-ms-viewport {
    width: 320px;
/* the viewport for small devices is set to 320px  */
  }
  @-o-viewport {
    width: device-width;
  }
  @viewport {
    width: device-width;
  }
}
@foo bar1 {
  color: #f00;
}
@foo bar2 {
  color: #f00;
}
@foo bar3 {
  color: #f00;
}
@foo bar4 {
  color: #f00;
}
@foo bar5 {
  color: #f00;
}
.foo {
  width: 1000px;
}
@font-face {
  font-family: 'Arial-1';
}
@font-face {
  font-family: 'Arial-2';
}
@foo {
  .bar {
    color: #f00;
  }
}
@foo bar baz;
