
if false
  something
    with a-prop

if true
  form
    input
      border 1px solid #eee

  [type='text']
    margin 0

  input[type='text']
    display none

  input[type='password'], select
    background #eee

  if true
    body
      font 12px

if true
  caption[attr='foo'] + th:first-child
    color red

if true
  div > div:first-child > :first-child
    color blue
