
form
  .foo
    color black
    .bar
      padding 5px
      color red

body
  .foo
    .bar
      display none

body
  .foo
  .bar
    .baz
    .sdf
      display none

.foo
.bar
  .baz
  .raz
    something 'else'

.foo
.bar
  .baz
  .raz
    background red
    .ASDF
      background white

.circle
  img
  .cap-overlay
  .cap-soldout
    border-radius 200px

if true
  tag .class
  bar
    foo bar
