
test(n)
  n += 5
  n += 5

body
  foo test(10)

test(n)
  n -= 2
  n -= 3

body
  foo test(10)

test(n)
  n *= 2
  n *= 2

body
  foo test(5)

test(n)
  n /= 2
  n /= 4

body
  foo test(20)

test(n)
  n %= 2

body
  foo test(5)