
mixin(n)
  padding n
  var = 'bar'
  color var
  .foo
    color var
    .bar
      color var

body
  foo = 'foo'
  mixin(5px)

three(n)
  three n
  with some nesting
    four n = n + 1
    even more
      five n + 1

two(n)
  two n
  three(n + 1)

one(n)
  one n
  two(n + 1)

body
  one(1)