form input:last-child {
  display: none;
}
form input:nth-child(15) {
  display: none;
}
.prefix-grid-1 {
  width: 100px;
}
.prefix-grid-2 {
  width: 200px;
}
.prefix-grid-3 {
  width: 300px;
}
.prefix-grid-4 {
  width: 400px;
}
.prefix-grid-5 {
  width: 500px;
}
body form input:last-child {
  display: none;
}
ul li:nth-child(2) {
  display: none;
}
foo bar {
  foo: bar;
}
foo bar baz {
  foo: bar;
}
foo {
  two: 2;
}
foo bar {
  one: 1;
}
foo bar baz {
  foo: bar;
}
one * {
  one: 1;
  two: 2;
  three: 3;
}
two * {
  one: 1;
  two: 2;
  three: 3;
}
three * {
  one: 1;
  two: 2;
  three: 3;
}
li a:active {
  color: #000;
  background: #fff;
}
li a:active {
  color: #000;
  background: #fff;
}
.prefix-col-1-0 :nth-child(1) {
  foo: 'bar';
}
.prefix-col-1 {
  foo: 'bar';
}
.prefix-col-2 {
  foo: 'bar';
}
.prefix-col-3 {
  foo: 'bar';
}
@media print {
  blockquote {
    border: 1px solid #999;
  }
  blockquote {
    border: 1px solid #999;
  }
  blockquote {
    border: 1px solid #999;
  }
  blockquote {
    border: 1px solid #999;
  }
}
