html {
  background: #dadada;
  background: -moz-linear-gradient(-90deg, #fff, #dadada) fixed;
  background: -webkit-gradient(linear, left top, left bottom, from(#fff), to(#dadada)) fixed;
}
body {
  padding: 120px 150px;
  font: 14px / 1.4 "helvetica neue", helvetica, arial, sans-serif;
  color: #484848;
}
h1,
h2,
h3 {
  color: #222;
}
h1 a,
h2 a,
h3 a {
  color: #222;
}
h1 a:hover,
h2 a:hover,
h3 a:hover {
  text-decoration: none;
}
h1 {
  margin: 10px 0 15px 0;
  font-weight: bold;
  font-size: 60px;
}
h2 {
  margin: 0;
  font-size: 18px;
}
h3 {
  font-size: 14px;
}
a {
  text-decoration: none;
  color: #b90101;
}
a:hover {
  text-decoration: underline;
}
strong {
  color: #a00;
}
ul {
  margin: 0;
  padding: 0 25px;
}
ul li {
  list-style: square;
}
.tagline {
  margin: 0;
  padding: 0;
}
.tagline em {
  font-style: normal;
}
.tagline em.expressive {
  color: #222;
}
.tagline em.dynamic {
  color: #555;
}
.tagline em.robust {
  color: #888;
}
.tagline em.css {
  color: #bbb;
}
#container {
  text-align: center;
}
#container #content {
  margin: 0 auto;
  padding-top: 40px;
  width: 300px;
  text-align: left;
}
#menu {
  position: fixed;
  top: -5px;
  right: 60px;
  margin: 0;
  padding: 15px 0 10px 5px;
  background: rgba(255,255,255,0.3);
  border: 1px solid #ddd;
  text-align: left;
  -moz-box-shadow: inset rgba(34,34,34,0.1) 0 4px 4px;
  -webkit-box-shadow: inset rgba(34,34,34,0.1) 0 4px 4px;
  box-shadow: inset rgba(34,34,34,0.1) 0 4px 4px;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
}
#menu li {
  list-style: none;
}
#menu li a {
  display: block;
  width: 150px;
  padding: 1px 10px;
  color: #7b7b7b;
  font-size: 13px;
}
#menu li a:hover {
  color: #000;
  text-decoration: none;
}
.example {
  margin-top: 25px;
}
pre {
  width: 300px;
  padding: 30px;
  color: #8d8d8d;
  font: 12px / 1.4 monaco, "helvetica neue", helvetica;
  overflow-x: auto;
  background: #fff;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  -moz-box-shadow: rgba(34,34,34,0.1) -1px -1px;
  -webkit-box-shadow: rgba(34,34,34,0.1) -1px -1px;
  box-shadow: rgba(34,34,34,0.1) -1px -1px;
}
pre.terminal {
  width: 340px;
  padding: 10px;
  background: #2b2b2b;
  color: #dadada;
  -moz-box-shadow: #fff -1px -1px;
  -webkit-box-shadow: #fff -1px -1px;
  box-shadow: #fff -1px -1px;
}
p code {
  padding: 2px 4px;
  color: #626262;
  font-size: 85%;
  background: #fff;
  -webkit-border-radius: 5px;
  -moz-border-radius: 5px;
  border-radius: 5px;
  -moz-box-shadow: rgba(34,34,34,0.1) -1px -1px;
  -webkit-box-shadow: rgba(34,34,34,0.1) -1px -1px;
  box-shadow: rgba(34,34,34,0.1) -1px -1px;
}
#ribbon {
  position: absolute;
  top: 2.5em;
  left: -3.75em;
  background-color: #a00;
  padding: 1px 0;
  overflow: hidden;
  -webkit-transform: rotate(-45deg);
  -moz-transform: rotate(-45deg);
  -moz-box-shadow: 1px 1px 3px rgba(0,0,0,0.3);
  -webkit-box-shadow: 1px 1px 3px rgba(0,0,0,0.3);
  box-shadow: 1px 1px 3px rgba(0,0,0,0.3);
}
#ribbon a {
  color: #fff;
  border: 1px solid #f18585;
  display: block;
  margin: 0.05em 0;
  padding: 0.5em 3.5em;
  text-align: center;
  text-decoration: none;
}
