@charset "utf-8";
body,
a,
section {
  width: 500px;
  margin: 0 auto;
}
body h2,
a h2,
section h2 {
  color: #008000;
}
/*# sourceMappingURL=data:application/json;charset=utf-8;base64,eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbImJhc2ljLmlubGluZS51dGYtOC5zdHlsIl0sIm5hbWVzIjpbXSwibWFwcGluZ3MiOiJBQUFTO0FBSVQ7QUFDQTtBQUNBO0VBQ0UsT0FBTyxNQUFQO0VBQ0EsUUFBUSxPQUFSOztBQUVBOzs7RUFDRSxPQUFPLFFBQVAiLCJmaWxlIjoiYmFzaWMuaW5saW5lLnV0Zi04LmNzcyIsInNvdXJjZXNDb250ZW50IjpbIkBjaGFyc2V0IFwidXRmLThcIlxuXG4kY29sb3IgPSByZWRcblxuYm9keVxuYVxuc2VjdGlvblxuICB3aWR0aDogNTAwcHhcbiAgbWFyZ2luOiAwIGF1dG9cblxuICBoMlxuICAgIGNvbG9yOiBncmVlblxuIl19 */
