
stringish(val = false)
  'string' == type(val) or 'ident' == type(val)

string(val)
  '' + val

body
  // false
  foo stringish(12)
  
  // true
  foo stringish('12')

  // true
  foo stringish(wahoo)

  // false
  num = 12
  foo stringish(num)
  foo stringish()

  foo string(something)
  foo string('something')
  foo string(12)