body
  background rgba(255,8,0,1)
  background rgba(255,255,0,0.2)
  background rgba(#fc0, 0.5)
  background rgba(255,255,0,0.25)
  background rgba(255,255,0,0.258)
  background rgba(255,255,0,0.2582)

  $alpha = 40%
  background rgba(#000, $alpha)
  background rgba(#000, $alpha)
  background rgba(0,0,0, $alpha)
  background rgba(0,0,0, $alpha)
