body {
  padding: 5px;
  padding: 5px 10px;
}
body {
  padding: 5px;
  padding: 5px 10px;
}
body {
  padding: 5px;
  padding: 5px 10px;
  padding: 5px 10px 0 2px;
}
body {
  test-y: 1px;
  test-y: 1px;
  padding: 2px 3px;
}
body {
  test-y: 1px;
  test-x: ;
  test-y: 1px;
  test-x: 2px;
}