@charset 'utf-8';
@charset "utf-8";
@import url("foo.css");
@import 'foo.css';
@import "foo.css";
@media screen and (min-height: 500px) {
  body {
    color: #f00;
  }
}
@-moz-document url-prefix() {
  body {
    color: #f00;
  }
}
@page {
  margin: 0;
}
@keyframes foo {
  0% {
    width: 400px;
  }
  50%, 75% {
    width: 300px;
  }
  100% {
    width: 200px;
  }
}
@namespace svg "http://www.w3.org/2000/svg";
@host {
  body {
    color: #f00;
  }
}
@supports (display: flex) {
  div {
    display: flex;
  }
}
@font-face {
  font-family: "Bitstream Vera Serif Bold";
  src: url("http://developer.mozilla.org/@api/deki/files/2934/=VeraSeBd.ttf");
}
