n = false

if !n
  n = 100

body
  padding n

n = false

if not not n
  n = 50

body
  padding n

if not n
  n = 150

body
  padding n

if n
  n = n / 2
else
  n = 10000

body
  padding n

if n > 100
  n = n * 2
else
  n = -1

body
  padding n

n = 75

if n < 50
  n = n
else
  if n > 50 and n < 100
    n = 1
  else
    n = -1

body
  padding n

negative(n)
  unless n is a 'unit'
    return invalid
  if n < 0
    yes
  else if n > 0
    no
  else
    zero

body
  foo negative(-5)
  foo negative(5)
  foo negative(0)
  foo negative('asdf')

body
  .input
    pad = true
    margin = false
    if pad
      padding 5px
    if margin
      margin 5px
    else
      no unquote('margin')

mixin()
  foo bar
  bar baz

body
  form input
    if true
      foo negative(5)
      mixin()
  something
    mixin()

body
  .nested
    if true
      if true
        if true
          foo bar
          .hidden
            if true
              display none

a = 10

if a == 10 {
  body {
    foo a
  }
}
