
body
  foo opposite-position()
  foo opposite-position(top) == bottom
  foo opposite-position(left) == right
  foo opposite-position(top left)[0] == bottom
  foo opposite-position(top left)[1] == right
  foo opposite-position(center) == center
  val = top left
  foo opposite-position(val)