body {
  padding: 5px;
}
body {
  padding: 5px;
}
body {
  padding: 5px;
  margin: 0;
}
body {
  padding: 5px;
  margin: 0;
}
body {
  padding: 5px;
  margin: 0;
}
body {
  padding: 5px;
  margin: 0;
}
body {
  padding: 5px;
}
ul li {
  padding: 5px;
}
body {
  padding: 5px;
}
foo bar {
  color: 'asdf';
}
foo bar {
  color: 'asdf';
}