body {
  foo: 4;
  foo: 4;
  foo: -5px;
  foo: 2;
  foo: 2;
}
body {
  foo: true;
  foo: true;
}
body {
  foo: 5;
  foo: 5;
}
body {
  foo: true;
  foo: true;
  foo: true;
  foo: true;
  foo: 2;
}
body {
  foo: true;
  foo: true;
}
body {
  foo: 2.5;
  foo: 2.5;
}
body {
  foo: true;
  foo: true;
  foo: false;
  foo: wahoo;
  foo: fail;
}
body {
  foo: true;
  foo: true;
}
body {
  foo: true;
  foo: 1;
}
body {
  foo: true;
  foo: true;
  foo: false;
  foo: true;
}