no-bullet()
  list-style-image none
  list-style-type none
  margin-left 0

inline-block()
  display -moz-inline-box
  -moz-box-orient vertical
  display inline-block
  vertical-align middle

inline-block-list-item(padding = false)
  no-bullet()
  inline-block()
  if padding
    padding-left 5px
    padding-right 5px

ul
  li
    inline-block-list-item()

ul li:first-child
  inline-block-list-item(true)

pad(pad = false, margin = false)
  if pad
    padding 5px
  if margin
    margin 5px
  unless pad or margin
    did nothing

body
  pad()

body
  pad(true)

body
  pad(true, true)

qux()
  test bar
  test baz

foo()
  bar = 1
  baz = 2
  qux()

body
  foo()
