
h1#logo
  margin-top - - - 15px
  margin-left ~ - 4px
  foo !true
  foo !!0
  foo !-1
  foo !99
  foo !((99))
  foo not not 0
  foo 0px -2px -3px
  foo -2px --3px

body
  text-indent -99999px
  background #fff url('/some/image.png') no-repeat -29px 1px
