body {
  foo: 1;
  foo: 2;
  foo: 3;
  foo: 4;
  foo: 5;
  foo: 6;
  foo: 7;
}
body {
  foo: 3;
}
body {
  foo: true;
  foo: true;
}
body {
  foo: true;
  foo: true;
}
body {
  foo: 5;
}
body {
  foo: bar;
  foo: baz;
}
body {
  foo: bar;
  foo: baz;
}
@import 'foo.css';
body {
  foo: 5;
}
body {
  foo: string;
  foo: number;
  foo: unknown;
}
body {
  foo: true;
  foo: true;
  foo: false;
}
body {
  fonts: arial, sans-serif;
}
body {
  foo: yes;
  foo: yes;
  foo: yes;
  foo: ;
  foo: ;
}
body {
  foo: yes;
  foo: no;
  foo: zero;
  foo: invalid;
}
