
@media print and (width: 21cm) and (height: 29cm)
  body
    margin 3cm
    padding 0

@media print
  @page :left
    margin-left 5px
  @page :right
    margin-right 5px

.foo
  if true {
    width 50%
    @media screen and (max-width: 500px) {
      width 100%
    }
  }

.bar
  if false {
    // nothing
  } else if true {
    width 50%
    @media screen and (max-width: 500px) {
      width 100%
    }
  }

.baz
  if false {
    // nothing
  } else {
    width 50%
    @media screen and (max-width: 500px) {
      width 100%
    }
  }

.quux
  font-weight bold
  @media screen
    if false
      background-position 45px 0px
    else
      background-position 100px 0px
