
#wrapper
  padding 5px
  white-space nowrap

#wrapper
  background: url('http://example.net/bar.png'),
    #333

#wrapper
  background: url('http://example.net/bar.png'),
    url("http://example.net/baz.png")

#wrapper
	background-image:
		linear-gradient(
			top,
			rgba(0, 0, 0, 0.3) 0,
			rgba(0, 0, 0, 0) 20%,
			rgba(0, 0, 0, 0) 80%,
			rgba(0, 0, 0, 0.3) 100%
		);
