args(n = null)
  length(n)

vargs(args...)
  length(args)

arguments()
  length(arguments)

body
  foo length()
  foo length(args())
  foo length(1)
  foo length((1 2) (3 4))
  foo length(1 2 3)
  foo length("hey")
  foo vargs(1, 2, 3, 4)
  foo args(1 2 3 4 5)
  foo arguments(1,2,3,4,5,6)
