.button {
  padding: 5px;
  -webkit-transition: opacity 1s ease-out;
}
.button:hover {
  opacity: 2;
}
textarea,
input {
  color: #a7a7a7;
}
textarea:hover,
input:hover {
  color: #000;
}
.dim {
  opacity: 0.2;
}
.dim:hover,
.dim.show {
  opacity: 1;
}
body #login {
  -webkit-box-shadow: 1px 1px 3px #eee;
  -moz-box-shadow: 1px 1px 3px #eee;
  box-shadow: 1px 1px 3px #eee;
}
html.ie8 body #login,
html.ie7 body #login foo,
html.ie6 body #login {
  border: solid 1px #eee;
}
.test {
  display: inline;
}
div.test,
p.test {
  display: block;
}
