/*
 * Reset button related properties so that
 * a, button, and input's are supported.
 */
/*
 * Minimalistic flat button with white inset.
 */
button,
a.button {
  display: block;
  text-decoration: none;
  background: #e3e3e3;
  border: 1px solid #bdbdbd;
  border-radius: 3px;
  box-shadow: inset 0 0 1px 1px rgba(255,255,255,0.8);
  color: #333;
  font-family: 'helvetica neue', helvetica, arial, sans-serif;
  font-size: 12px;
  font-weight: bold;
  line-height: 1;
  padding: 8px 0 9px;
  text-align: center;
  text-shadow: 0 1px 0 #fff;
  width: 150px;
}
button:hover,
a.button:hover {
  background: #dbdbdb;
  box-shadow: inset 0 0 1px 1px rgba(255,255,255,0.5);
  color: #222;
  cursor: pointer;
}
button:active,
a.button:active {
  background: #d6d6d6;
  box-shadow: inset 0 0 1px 1px rgba(255,255,255,0.2);
  color: #000;
}