body {
  test-args: 1 2 3;
  foo: 1;
  foo: 2;
  foo: 3;
  test-args: 1 2 3 4 5;
  foo: 1 2;
  foo: 3 4;
  foo: 5;
  test-args: 1 2 3 4;
  foo: 1 2;
  foo: 3 4;
}
body {
  foo: 1 2;
  foo: 3 4;
}
body {
  foo: 1;
  foo: 2;
  foo: 3;
  foo: 4;
  foo: 5;
}
body {
  foo: 1;
  foo: 2;
  foo: 3;
}
body foo {
  bar: 1;
}
body foo {
  bar: 2;
}
body foo {
  bar: 3;
}
body {
  bar: 1;
  bar: 2;
  bar: 3;
}
body foo bar {
  baz: 1;
}
body foo bar {
  baz: 2;
}
body foo bar {
  baz: 3;
}
body {
  foo: 0 foo;
  foo: 1 bar;
  foo: 2 baz;
}